@@ -14,14 +14,16 @@ A small library for parsing configuration files.
 Supports secsie and ini formats. Not suitable for writing .ini files, but reads them just fine.
 """
 
-__version__ = 'v1.0.3'
+__version__ = 'v2.0.0'
 __author__ = 'Noah Broyles'
 
 
 __all__ = [
     'InvalidSyntax',
+    'parse_config',
     'parse_config_file',
-    'generate_config'
+    'generate_config',
+    'generate_config_file'
 ]
 
 MODES = {
@@ -86,13 +88,10 @@ def _write_to_conf_(conf: dict, line, line_number: int, section=None, mode: str
     return conf
 
 
-def parse_config_file(conf_file: str, mode: str = 'secsie') -> dict:
-    """
-    Reads a config file and returns a dictionary of the values inside.
-    """
-    with open(conf_file, 'r') as f:
-        lines = [l.strip('\n') for l in f.readlines()]
+def parse_config(config: str, mode: str = 'secsie') -> dict:
+    lines = config.split('\n')
     conf = {}
+
     c_section = None
     lineno = 0
     for line in lines:
@@ -111,17 +110,24 @@ def parse_config_file(conf_file: str, mode: str = 'secsie') -> dict:
     return conf
 
 
-def generate_config(obj: dict, output_file: str = None) -> str:
+def parse_config_file(conf_file: str, mode: str = 'secsie') -> dict:
+    """
+    Reads a config file and returns a dictionary of the values inside.
+    """
+    with open(conf_file, 'r') as f:
+        config = f.read()
+
+    return parse_config(config, mode=mode)
+
+
+def generate_config(conf_obj: dict) -> str:
     """Generates and returns a valid config from an object.
     Will save the config if an output file is passed.
     
     This WILL NOT write valid .ini files, so don't even try. The only output format is secsie."""
-    if output_file is not None:
-        output_file = Path(output_file)
-        conf = f"# {output_file.name} auto-generated by secsie\n\n"
-    else:
-        conf = ''
-    for key, value in obj.items():
+
+    conf = ''
+    for key, value in conf_obj.items():
         if isinstance(value, dict):
             conf += f"\n[{key.replace(' ', '')}]\n"
             for k, v in value.items():
@@ -130,8 +136,13 @@ def generate_config(obj: dict, output_file: str = None) -> str:
             continue
         conf += f"{key} = {value}\n"
 
-    if output_file is not None:
-        with open(output_file, 'w') as f:
-            f.write(conf)
-
     return conf
+
+
+def generate_config_file(conf_obj: dict, output_file: str):
+    
+    output_file = Path(output_file)
+    conf = generate_config(conf_obj)
+    
+    with open(output_file, 'w') as f:
+        f.write(f"# {output_file.name} auto-generated by secsie\n{conf}")
